==> dl.php?src=linea21_1_0.zip: linea21/workshop/lock_com.php <==
<?php
include_once("../lib/lib_common.php"); 

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

if(isset($_POST['com_id']))	$com_id=$_POST['com_id'];
if(isset($_GET['com_id']))	$com_id=$_GET['com_id'];

if(isset($_POST['mes_id']))	$mes_id=$_POST['mes_id'];
if(isset($_GET['mes_id']))	$mes_id=$_GET['mes_id'];

if(isset($_POST['lock']))	$lock=$_POST['lock'];
if(isset($_GET['lock']))	$lock=$_GET['lock'];

//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////  
if (WorkshopAuth_id(GetSessionElement('id'), $sql_object, $id)<>true && !IsSuperAdmin())
ReloadIndex('admin');  
////////////



$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_add_com=$rub_link."&amp;todo=add_com&amp;id=".$id."&amp;com_id=";
$link_list_com=$rub_link."&todo=list_com&id=".$id."";
$link_cancel=$rub_link."&amp;todo=list_com&amp;id=".$id;

if(isset($_POST['annuler'])) {
	header("Location: ".$link_list_com);
}

$workshop_com_object= new workshop_com;

$req_com_mes = SQL_getOnetopicWorkcom($id, $mes_id, $mes_id);
$result_com_mes = $sql_object -> DBSelect($req_com_mes);
$com_root_subject=formatText($result_com_mes[0]['workcom_subject'], '2HTML');


if(isset($_POST['valider'])) {

	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&id=".$id;
	$result=$workshop_com_object->LockCom($id, $mes_id, $com_id, $lock, $sql_object);
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

$req_det= SQL_getoneCompleteWorkshop($id);
$result=$sql_object->DBSelect($req_det);

if(count($result)>1) exit();
$workshop_denomination=FormatText($result[0]['workshop_denomination'], '2HTML');
$titleh2=$GLOBALS['lang']['workshop']['com_name']." : ".$com_root_subject." (".$GLOBALS['lang']['workshop']['name']." :".$workshop_denomination.")";
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home'] ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['workshop']?></a>
		</li>
		<li>
			<span><? 
			if ($lock==0) echo formatnavTitle($GLOBALS['lang']['workshop']['lock_com']." : ". $com_root_subject." (".$GLOBALS['lang']['workshop']['name']." :".$workshop_denomination.")");
			else  echo formatnavTitle($GLOBALS['lang']['workshop']['unlock_com']." : ". $com_root_subject." (".$GLOBALS['lang']['workshop']['name']." :".$workshop_denomination.")"); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<?php afflinkbar($todo,$id, $lang); ?>
<h2><? echo formatTitleh2($titleh2); ?></h2>
<form id="lockcom" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<div class="info" id="truetransfert1">
<?php if ($lock==0) echo $GLOBALS['lang']['workshop']['lock_com_warning'];
else echo $GLOBALS['lang']['workshop']['unlock_com_warning']; 
?>
</div>
<div class="info" id="truetransfert2">
<? if ($lock==0) echo $GLOBALS['lang']['workshop']['lock_com_warning2'];
else echo $GLOBALS['lang']['workshop']['unlock_com_warning2']; ?>
</div>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="lock" type="hidden" value="<?php echo $lock; ?>" />
<input name="mes_id" type="hidden" value="<?php echo $mes_id; ?>" />
<input name="com_id" type="hidden" value="<?php echo $com_id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<? echo cancel_button($link_cancel); ?>
<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>

==> dl.php?src=linea21_1_3_1.zip: linea21/workshop/lock_com.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage workshop
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

include_once("../lib/lib_common.php"); 

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

if(isset($_POST['com_id']))	$com_id=$_POST['com_id'];
if(isset($_GET['com_id']))	$com_id=$_GET['com_id'];

if(isset($_POST['mes_id']))	$mes_id=$_POST['mes_id'];
if(isset($_GET['mes_id']))	$mes_id=$_GET['mes_id'];

if(isset($_POST['lock']))	$lock=$_POST['lock'];
if(isset($_GET['lock']))	$lock=$_GET['lock'];

//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////  
if (WorkshopAuth_id(GetSessionElement('id'), $sql_object, $id)<>true && !IsSuperAdmin())
ReloadIndex('admin');  
////////////



$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_add_com=$rub_link."&amp;todo=add_com&amp;id=".$id."&amp;com_id=";
$link_list_com=$rub_link."&todo=list_com&id=".$id."";
$link_cancel=$rub_link."&amp;todo=det_com&amp;id=".$id."&amp;com_id=".$com_id;

if(isset($_POST['annuler'])) {
	header("Location: ".$link_list_com);
}

$workshop_com_object= new workshop_com;

$req_com_mes = SQL_getOnetopicWorkcom($id, $mes_id, $mes_id);
$result_com_mes = $sql_object -> DBSelect($req_com_mes);
$com_root_subject=formatText($result_com_mes[0]['workcom_subject'], '2HTML');


if(isset($_POST['valider'])) {

	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&id=".$id."&com_id=".$com_id;
	
	$result=$workshop_com_object->LockCom($id, $mes_id, $com_id, $lock, $sql_object);
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

$req_det= SQL_getoneCompleteWorkshop($id);
$result=$sql_object->DBSelect($req_det);

if(count($result)>1) exit();
$workshop_denomination=FormatText($result[0]['workshop_denomination'], '2HTML');
$titleh2=_t('workshop','com_name')." : ".$com_root_subject." ("._t('workshop','name')." :".$workshop_denomination.")";
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php" class="chemin_home"><? echo _t('way','home') ?></a>
		</li>
		<li>
			   <a href="<?php echo $rub_link; ?>" id="chemin_<? echo $rub; ?>" class="chemin_rub"><? echo _t('menu','workshop')?></a>
		</li>
		<li>
			<span><? 
			if ($lock==0) echo formatnavTitle(_t('workshop','lock_com')." : ". $com_root_subject." ("._t('workshop','name')." :".$workshop_denomination.")");
			else  echo formatnavTitle(_t('workshop','unlock_com')." : ". $com_root_subject." ("._t('workshop','name')." :".$workshop_denomination.")"); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once(THEME_ADMIN_PATH."quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<?php afflinkbar($todo,$id, $lang); ?>
<h2><? echo formatTitleh2($titleh2); ?></h2>
<form id="lockcom" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<div class="info" id="truetransfert1">
<?php if ($lock==0) echo _t('workshop','lock_com_warning');
else echo _t('workshop','unlock_com_warning'); 
?>
</div>
<div class="info" id="truetransfert2">
<? if ($lock==0) echo _t('workshop','lock_com_warning2');
else echo _t('workshop','unlock_com_warning2'); ?>
</div>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="lock" type="hidden" value="<?php echo $lock; ?>" />
<input name="mes_id" type="hidden" value="<?php echo $mes_id; ?>" />
<input name="com_id" type="hidden" value="<?php echo $com_id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<? echo cancel_button($link_cancel); ?>
<input name="valider" type="submit" value="<? echo _t('btn','valid') ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>
